//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Mask/MaskEditorPropertyPanel.h
//! @brief     Defines class MaskEditorPropertyPanel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_MASK_MASKEDITORPROPERTYPANEL_H
#define BORNAGAIN_GUI_VIEW_MASK_MASKEDITORPROPERTYPANEL_H

#include "GUI/View/Mask/MaskEditorFlags.h"
#include <QModelIndex>
#include <QWidget>

class QListView;
class SessionModel;
class ComponentTreeView;
class QItemSelection;
class QItemSelectionModel;
class IntensityDataItem;

//! Tool widget for MaskEditor

class MaskEditorPropertyPanel : public QWidget {
    Q_OBJECT
public:
    MaskEditorPropertyPanel(QWidget* parent = nullptr);

    QSize sizeHint() const override;
    QSize minimumSizeHint() const override;

    void setMaskContext(SessionModel* model, const QModelIndex& maskContainerIndex,
                        IntensityDataItem* intensityItem);

    void resetContext();

    QItemSelectionModel* selectionModel();

    void setPanelHidden(bool value);

signals:
    void itemContextMenuRequest(const QPoint& point);

private slots:
    void onSelectionChanged(const QItemSelection& selected, const QItemSelection&);
    void onCustomContextMenuRequested(const QPoint& point);

private:
    QListView* m_listView;
    ComponentTreeView* m_maskPropertyEditor;
    ComponentTreeView* m_plotPropertyEditor;
    SessionModel* m_maskModel;
    QModelIndex m_rootIndex;
    IntensityDataItem* m_intensityDataItem;
};

#endif // BORNAGAIN_GUI_VIEW_MASK_MASKEDITORPROPERTYPANEL_H
