//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/PropertyEditor/ComponentTreeView.h
//! @brief     Defines class ComponentTreeView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_PROPERTYEDITOR_COMPONENTTREEVIEW_H
#define BORNAGAIN_GUI_VIEW_PROPERTYEDITOR_COMPONENTTREEVIEW_H

#include <QWidget>
#include <memory>

class QTreeView;
class SessionModel;
class SessionModelDelegate;
class ComponentProxyModel;
class QModelIndex;
class SessionItem;
class QStandardItemModel;
class RightMouseButtonEater;

//! Component property tree for SessionItems.
//! Shows only PropertyItems and current items of GroupProperties.

class ComponentTreeView : public QWidget {
    Q_OBJECT
public:
    ComponentTreeView(QWidget* parent = nullptr);

    void setItem(SessionItem* item);
    void clearEditor();

    void setShowHeader(bool show);

private slots:
    void onCustomContextMenuRequested(const QPoint& pos);

private:
    void setModel(SessionModel* model);
    void setRootIndex(const QModelIndex& index);

    QTreeView* m_tree;
    SessionModelDelegate* m_delegate;
    ComponentProxyModel* m_proxyModel;
    QStandardItemModel* m_placeHolderModel;
    std::unique_ptr<RightMouseButtonEater> m_eventFilter;
};

#endif // BORNAGAIN_GUI_VIEW_PROPERTYEDITOR_COMPONENTTREEVIEW_H
